# PyHuTool
### Python版HuTool
PyHuTool draws lessons from Java's Hutool to reduce the learning cost of related APIs and improve work efficiency
```
pip install pyautogui
```
Full documentation available at https://pyhutool.readthedocs.org
